@@ -14,20 +14,24 @@ __PACKAGE__->config(
   }
 );
 
-sub request : Chained('/') Args(0) Does('OAuth2::RequestAuth') {}
+sub base :Chained('/') PathPart('') CaptureArgs(0) {}
 
-sub grant : Chained('/') Args(0) Does('OAuth2::GrantAuth') {
+sub request : Chained('base') Args(0) Does('OAuth2::RequestAuth') {}
+
+sub grant : Chained('base') Args(0) Does('OAuth2::GrantAuth') {
   my ( $self, $c ) = @_;
 
   my $oauth2 = $c->req->oauth2;
 
   $c->user_exists and $oauth2->user_is_valid(1)
     or $c->detach('/passthrulogin');
+
+  $oauth2->approved(1) if $c->req->query_parameters->{approved};
 }
 
-sub token : Chained('/') Args(0) Does('OAuth2::AuthToken::ViaAuthGrant') {}
+sub token : Chained('base') Args(0) Does('OAuth2::AuthToken::ViaAuthGrant') {}
 
-sub refresh : Chained('/') Args(0) Does('OAuth2::AuthToken::ViaRefreshToken') {}
+sub refresh : Chained('base') Args(0) Does('OAuth2::AuthToken::ViaRefreshToken') {}
 
 
 1;
